;; Generated package description from llm.el  -*- no-byte-compile: t -*-
(define-package "llm" "0.23.0" "Interface to pluggable llm backends" '((emacs "28.1") (plz "0.8") (plz-event-source "0.1.1") (plz-media-type "0.2.1")) :commit "874d76211c6933f2f5e41583a495e9b3aee51fb3" :authors '(("Andrew Hyatt" . "ahyatt@gmail.com")) :maintainer '("Andrew Hyatt" . "ahyatt@gmail.com") :url "https://github.com/ahyatt/llm")
